# -*- coding: utf-8 -*-
"""EDAM data packaged as a Python module."""

# EDAMmajorversion.EDMAminorversion.pythonprojectdotversion
__version__ = '1.25.2.dev0'


PROJECT_NAME = "edam-ontology"
GITHUB_PROJECT_NAME =  "edam-ontology.py"
PROJECT_OWNER = PROJECT_USERAME = "edamontology"
PROJECT_AUTHOR = 'edamontology'
PROJECT_EMAIL = 'jmchilton@gmail.com'

PROJECT_URL = "https://github.com/edamontology/edam-ontology.py"
RAW_CONTENT_URL = "https://raw.github.com/%s/%s/main/" % (
    PROJECT_USERAME, GITHUB_PROJECT_NAME
)



"""Return text streams to EDAM data.

Keep parsing and such to minimum to maintain maximum backward compatibility.
"""
from io import TextIOWrapper
from typing import TextIO

from pkg_resources import resource_stream


def tabular_stream() -> TextIO:
    """Yield EDAM data in TSV format as a Python UTF-8 encoded text stream."""
    return TextIOWrapper(resource_stream("edam_ontology", 'EDAM.tsv'), encoding='utf-8')



#!/usr/bin/env python
# -*- coding: utf-8 -*-

import ast
import os
import re
import sys
try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

if sys.version_info < (3, 5):
    sys.stderr.write("ERROR: edam-data requires at least Python Version 3.5\n")
    sys.exit(1)

SOURCE_DIR = "edam_ontology"

_version_re = re.compile(r'__version__\s+=\s+(.*)')


with open('%s/__init__.py' % SOURCE_DIR, 'rb') as f:
    init_contents = f.read().decode('utf-8')

    def get_var(var_name):
        pattern = re.compile(r'%s\s+=\s+(.*)' % var_name)
        match = pattern.search(init_contents).group(1)
        return str(ast.literal_eval(match))

    version = get_var("__version__")
    PROJECT_NAME = get_var("PROJECT_NAME")
    PROJECT_URL = get_var("PROJECT_URL")
    PROJECT_AUTHOR = get_var("PROJECT_AUTHOR")
    PROJECT_EMAIL = get_var("PROJECT_EMAIL")

TEST_DIR = 'tests'
PROJECT_DESCRIPTION = 'Versioned, Python packaged EDAM ontology (http://edamontology.org/) data.'
PACKAGES = [
    'edam_ontology',
]
ENTRY_POINTS = '''
    [console_scripts]
'''
PACKAGE_DATA = {
    'edam_ontology': [
        '**',
    ],
}
PACKAGE_DIR = {
    SOURCE_DIR: SOURCE_DIR,
}

with open('README.rst') as fh:
    readme = fh.read()
with open('HISTORY.rst') as fh:
    history = fh.read().replace('.. :changelog:', '')

if os.path.exists("requirements.txt"):
    with open("requirements.txt") as fh:
        requirements = [r for r in fh.read().split("\n") if ";" not in r]
else:
    # In tox, it will cover them anyway.
    requirements = []

test_requirements = [
    # TODO: put package test requirements here
]


setup(
    name=PROJECT_NAME,
    version=version,
    description=PROJECT_DESCRIPTION,
    long_description=readme + '\n\n' + history,
    long_description_content_type="text/x-rst",
    author=PROJECT_AUTHOR,
    author_email=PROJECT_EMAIL,
    url=PROJECT_URL,
    packages=PACKAGES,
    entry_points=ENTRY_POINTS,
    package_data=PACKAGE_DATA,
    package_dir=PACKAGE_DIR,
    include_package_data=True,
    install_requires=requirements,
    license="MIT",
    zip_safe=False,
    keywords='EDAM',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Environment :: Console',
        'License :: OSI Approved :: MIT License',
        'Operating System :: POSIX',
        'Topic :: Software Development',
        'Topic :: Software Development :: Code Generators',
        'Topic :: Software Development :: Testing',
        'Natural Language :: English',
        "Programming Language :: Python :: 3",
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
    ],
    test_suite=TEST_DIR,
    tests_require=test_requirements
)
